@@ -98,7 +98,7 @@ def continued_fraction(x):
 
     :param x: An integer
 
-    :returns: A list containing the continued fraction of n
+    :returns: A list containing the continued fraction of x
     
     .. code-block:: python
     
@@ -436,4 +436,62 @@ def ChineseRemainderTheorem(a1, a2, n1, n2):
     #The unique solution to this system is a1*q*n2 + a2*p*n1 % n1*n2
     return (a1*q*n2+ a2*p*n1) % (n1*n2)
 
+def FrobeniusNumber(*integers):
+    '''
+    Generates the `Frobenius Number <https://en.wikipedia.org/wiki/Coin_problem>`_ for a set A
+    Given positive integers a1, a2, ..., an such that gcd(a1, a2, ..., an) = 1, the largest integer that cannot be expressed as an integer conical combination of these numbers, i.e., as a sum
+    k1*a1 + k2*a2 + ··· + kn*an, is called the Frobenius number.
+    
+    The below algorithm is based off `Faster Algorithms for Frobenius Numbers <https://www.cis.upenn.edu/~cis511/Frobenius-numbers-Nijenhuis-Wagon.pdf>`_
+    The following is an implementation of their Breadth-First Method
+
+    :param A: A list of integers
+
+    :returns: Frobenius number 
+    
+    .. code-block:: python3
+    
+        print(FrobeniusNumber([3, 5])) #7
+        print(FrobeniusNumber([6, 9, 20])) #43
+        print(FrobeniusNumber([1000, 1476, 3764, 4864, 4871, 7773])) #47350
+        
+    '''
+    #Set is first sorted
+    A = sorted(integers) 
+    #Initalize n value for future reference
+    n = len(A) 
+    #Initalize a1 and an for readability
+    a1 = A[0]
+    an = A[n - 1]
+    #Step 1
+    #Initalize FIFO queue
+    Q = [0]
+    #Initalize P
+    P = [0]*a1
+    P[0] = n
+    #Initalize S, label vector, in which each currently known minimal path weight to a vertex is stored.
+    S = [a1*an]*a1
+    S[0] = 0
+    #initalize Amod
+    Amod = [a % a1 for a in A]
+    #Step 2
+    while len(Q) != 0:
+        #Step 2a
+        v = Q.pop(0) #Remove the head of Q and set it to the vertex v
+        #Step 2b
+        for j in range(2, P[v] + 1):
+            #Step 2bi
+            u = v + Amod[j - 1]
+            if u >= a1:
+                u -= a1
+            #Step 2bii
+            w = S[v] + A[j - 1]
+            #Step 2biii
+            if w < S[u]:
+                S[u] = w
+                P[u] = j
+                if u not in Q:
+                    Q.append(u)
+    #Step 3
+    return max(S) - a1
 
